@@ -49,6 +49,29 @@ class SslClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CancelAuditCertificate(self, request):
+        """取消证书审核
+
+        :param request: Request instance for CancelAuditCertificate.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.CancelAuditCertificateRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.CancelAuditCertificateResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CancelAuditCertificate", params, headers=headers)
+            response = json.loads(body)
+            model = models.CancelAuditCertificateResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CancelCertificateOrder(self, request):
         """取消证书订单。
 
@@ -164,6 +187,29 @@ class SslClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateCertificateBindResourceSyncTask(self, request):
+        """创建证书绑定关联云资源异步任务， 该接口用于查询证书关联云资源。 若证书ID已存在查询云资源任务，则结果返回该任务ID。关联云资源类型，支持以下云资源：clb、cdn、waf、live、vod、ddos、tke、apigateway、tcb、teo（edgeOne）。查询关联云资源结果使用DescribeCertificateBindResourceTaskResult接口
+
+        :param request: Request instance for CreateCertificateBindResourceSyncTask.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.CreateCertificateBindResourceSyncTaskRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.CreateCertificateBindResourceSyncTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateCertificateBindResourceSyncTask", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateCertificateBindResourceSyncTaskResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateCertificateByPackage(self, request):
         """使用权益点创建证书
 
@@ -210,6 +256,29 @@ class SslClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteCertificates(self, request):
+        """批量删除证书，删除证书前支持查询证书是否关联了腾讯云云资源 （需自定义配置参数，参数名称：IsSync）
+
+        :param request: Request instance for DeleteCertificates.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.DeleteCertificatesRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.DeleteCertificatesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteCertificates", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteCertificatesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteManager(self, request):
         """删除管理人
 
@@ -325,6 +394,52 @@ class SslClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeCertificateBindResourceTaskDetail(self, request):
+        """查询CreateCertificateBindResourceSyncTask任务结果， 返回证书关联云资源异步任务结果， 支持以下云资源：clb、cdn、waf、live、vod、ddos、tke、apigateway、tcb、teo（edgeOne）
+
+        :param request: Request instance for DescribeCertificateBindResourceTaskDetail.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.DescribeCertificateBindResourceTaskDetailRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.DescribeCertificateBindResourceTaskDetailResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeCertificateBindResourceTaskDetail", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeCertificateBindResourceTaskDetailResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeCertificateBindResourceTaskResult(self, request):
+        """查询CreateCertificateBindResourceSyncTask任务结果， 返回证书关联云资源异步任务结果， 支持以下云资源：clb、cdn、waf、live、vod、ddos、tke、apigateway、tcb、teo（edgeOne）
+
+        :param request: Request instance for DescribeCertificateBindResourceTaskResult.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.DescribeCertificateBindResourceTaskResultRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.DescribeCertificateBindResourceTaskResultResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeCertificateBindResourceTaskResult", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeCertificateBindResourceTaskResultResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeCertificateDetail(self, request):
         """获取证书详情。
 
@@ -417,8 +532,31 @@ class SslClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeDeleteCertificatesTaskResult(self, request):
+        """查询批量删除任务结果
+
+        :param request: Request instance for DescribeDeleteCertificatesTaskResult.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.DescribeDeleteCertificatesTaskResultRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.DescribeDeleteCertificatesTaskResultResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDeleteCertificatesTaskResult", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeDeleteCertificatesTaskResultResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeDeployedResources(self, request):
-        """证书查询关联资源
+        """证书查询关联资源， 最新查询接口请使用CreateCertificateBindResourceSyncTask， 可以查询更多支持的云资源
 
         :param request: Request instance for DescribeDeployedResources.
         :type request: :class:`tencentcloud.ssl.v20191205.models.DescribeDeployedResourcesRequest`
@@ -440,6 +578,29 @@ class SslClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeDownloadCertificateUrl(self, request):
+        """获取下载证书链接
+
+        :param request: Request instance for DescribeDownloadCertificateUrl.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.DescribeDownloadCertificateUrlRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.DescribeDownloadCertificateUrlResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDownloadCertificateUrl", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeDownloadCertificateUrlResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeHostApiGatewayInstanceList(self, request):
         """查询证书apiGateway云资源部署实例列表
 
@@ -877,29 +1038,6 @@ class SslClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
-    def HostCertificate(self, request):
-        """云资源托管
-
-        :param request: Request instance for HostCertificate.
-        :type request: :class:`tencentcloud.ssl.v20191205.models.HostCertificateRequest`
-        :rtype: :class:`tencentcloud.ssl.v20191205.models.HostCertificateResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("HostCertificate", params, headers=headers)
-            response = json.loads(body)
-            model = models.HostCertificateResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(type(e).__name__, str(e))
-
-
     def ModifyCertificateAlias(self, request):
         """用户传入证书id和备注来修改证书备注。
 
@@ -946,6 +1084,29 @@ class SslClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyCertificateResubmit(self, request):
+        """针对审核失败或审核取消的付费证书，重新发起审核
+
+        :param request: Request instance for ModifyCertificateResubmit.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.ModifyCertificateResubmitRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.ModifyCertificateResubmitResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyCertificateResubmit", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyCertificateResubmitResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyCertificatesExpiringNotificationSwitch(self, request):
         """修改忽略证书到期通知。打开或关闭证书到期通知。
 
@@ -1062,7 +1223,7 @@ class SslClient(AbstractClient):
 
 
     def UpdateCertificateInstance(self, request):
-        """一键更新旧证书资源，本接口为异步接口， 调用之后DeployRecordId为0表示任务进行中， 当返回DeployRecordId大于0则表示任务创建成功。 未创建成功则会抛出异常
+        """一键更新旧证书资源，本接口为异步接口， 调用之后DeployRecordId为0表示任务进行中， 重复请求这个接口， 当返回DeployRecordId大于0则表示任务创建成功。 未创建成功则会抛出异常
 
         :param request: Request instance for UpdateCertificateInstance.
         :type request: :class:`tencentcloud.ssl.v20191205.models.UpdateCertificateInstanceRequest`
